unit Unit2;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls,
  JvTabBar, JvPageList, ExtCtrls;

type

  { TFormClaude }

  TFormClaude = class(TForm)
    JvTabBar1: TJvTabBar;
    JvPageList1: TJvPageList;
    Button1: TButton;
    Button2: TButton;
    Panel1: TPanel;
    procedure FormCreate(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure JvTabBar1TabSelected(Sender: TObject; Item: TJvTabBarItem);
  private
    FTabCounter: Integer;
    procedure CreateNewTab(const ACaption: string);
  public
  end;

var
  FormClaude: TFormClaude;

implementation

{$R *.lfm}

procedure TFormClaude.FormCreate(Sender: TObject);
begin
  FTabCounter := 0;

  // Initialer Tab und Seite
  CreateNewTab('Startseite');

  // Button-Beschriftungen
  Button1.Caption := 'Neuen Tab hinzufügen';
  Button2.Caption := 'Aktuellen Tab schließen';

  // Panel für Buttons positionieren
  Panel1.Height := 40;
  Panel1.Align := alTop;
  Button1.Parent := Panel1;
  Button2.Parent := Panel1;
  Button1.Left := 10;
  Button1.Top := 8;
  Button2.Left := 150;
  Button2.Top := 8;

  // JvTabBar und JvPageList konfigurieren
  JvTabBar1.Align := alTop;
  JvTabBar1.Height := 25;
  JvTabBar1.Parent := Self;

  JvPageList1.Align := alClient;
  JvPageList1.Parent := Self;

  Application.ProcessMessages;
end;

procedure TFormClaude.CreateNewTab(const ACaption: string);
var
  NewTab: TJvTabBarItem;
  NewPage: TJvStandardPage;
  Label1: TLabel;
  Memo1: TMemo;
begin
  // Neuen Tab in der TabBar erstellen
  NewTab := JvTabBar1.AddTab(ACaption);
  //NewTab.Caption := ACaption;
  NewTab.Tag := FTabCounter; // Für Referenzierung

  // Neue Seite in der PageList erstellen
  NewPage := TJvStandardPage.Create(Self);
 // JvPageList1.Pages.;
  NewPage.Parent := JvPageList1;
  NewPage.PageList := JvPageList1;
  NewPage.Caption := ACaption;
  NewPage.Tag := FTabCounter; // Gleicher Tag wie Tab

  // Beispiel-Inhalt für die neue Seite
  Label1 := TLabel.Create(NewPage);
  Label1.Parent := NewPage;
  Label1.Caption := 'Inhalt für: ' + ACaption;
  Label1.Left := 10;
  Label1.Top := 10;
  Label1.Font.Style := [fsBold];

  Memo1 := TMemo.Create(NewPage);
  Memo1.Parent := NewPage;
  Memo1.Left := 10;
  Memo1.Top := 40;
  Memo1.Width := 300;
  Memo1.Height := 200;
  Memo1.Lines.Add('Dies ist der Inhalt von Tab: ' + ACaption);
  Memo1.Lines.Add('');
  Memo1.Lines.Add('Sie können hier beliebigen Inhalt hinzufügen.');
  Memo1.Lines.Add('Jeder Tab hat seine eigene Seite.');

  // Neuen Tab aktivieren
  JvTabBar1.SelectedTab := NewTab;
  JvPageList1.ActivePage := NewPage;

  Inc(FTabCounter);
end;

procedure TFormClaude.Button1Click(Sender: TObject);
var
  TabName: string;
begin
  // Neuen Tab mit fortlaufender Nummerierung erstellen
  TabName := 'Tab ' + IntToStr(FTabCounter + 1);
  CreateNewTab(TabName);
end;

procedure TFormClaude.Button2Click(Sender: TObject);
var
  CurrentTab: TJvTabBarItem;
  CurrentPage: TJvCustomPage;
  TabIndex: Integer;
begin
  // Aktuellen Tab und zugehörige Seite löschen
  CurrentTab := JvTabBar1.SelectedTab;
  if Assigned(CurrentTab) and (JvTabBar1.Tabs.Count > 1) then
  begin
    TabIndex := CurrentTab.Index;

    // Zugehörige Seite finden und löschen
    if TabIndex < JvPageList1.PageCount then
    begin
      CurrentPage := JvPageList1.Pages[TabIndex];
      CurrentPage.Free;
    end;

    // Tab löschen
    JvTabBar1.Tabs.Delete(TabIndex);

    // Anderen Tab aktivieren falls verfügbar
    if JvTabBar1.Tabs.Count > 0 then
    begin
      if TabIndex > 0 then
        JvTabBar1.SelectedTab := JvTabBar1.Tabs[TabIndex - 1]
      else
        JvTabBar1.SelectedTab := JvTabBar1.Tabs[0];
    end;
  end;
end;

procedure TFormClaude.JvTabBar1TabSelected(Sender: TObject; Item: TJvTabBarItem);
var
  PageIndex: Integer;
begin
  // Entsprechende Seite in der PageList aktivieren
  if Assigned(Item) then
  begin
    PageIndex := Item.Index;
    if (PageIndex >= 0) and (PageIndex < JvPageList1.PageCount) then
      JvPageList1.ActivePage := JvPageList1.Pages[PageIndex];
  end;
end;

end.
